@@ -10,14 +10,19 @@ class GroupProperties(BaseModel):
     values: Optional[Dict[str, Any]]
 
 
+class GroupPropertiesList(BaseModel):
+    __root__: List[GroupProperties]
+
+
 class Charge(BaseModel):
     id: Optional[str]
     billable_metric_id: Optional[str]
     charge_model: Optional[str]
-    instant: Optional[bool]
+    pay_in_advance: Optional[bool]
+    invoiceable: Optional[bool]
     min_amount_cents: Optional[int]
     properties: Optional[Dict[str, Any]]
-    group_properties: Optional[GroupProperties]
+    group_properties: Optional[GroupPropertiesList]
 
 
 class Charges(BaseModel):
@@ -29,10 +34,11 @@ class ChargeResponse(BaseResponseModel):
     lago_billable_metric_id: Optional[str]
     billable_metric_code: Optional[str]
     charge_model: Optional[str]
-    instant: Optional[bool]
+    pay_in_advance: Optional[bool]
+    invoiceable: Optional[bool]
     min_amount_cents: Optional[int]
     properties: Optional[Dict[str, Any]]
-    group_properties: Optional[GroupProperties]
+    group_properties: Optional[GroupPropertiesList]
 
 
 class ChargesResponse(BaseResponseModel):
